wot.graphics package
====================

Submodules
----------

wot.graphics.color module
-------------------------

.. automodule:: wot.graphics.color
    :members:
    :undoc-members:
    :show-inheritance:

wot.graphics.plot module
------------------------

.. automodule:: wot.graphics.plot
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: wot.graphics
    :members:
    :undoc-members:
    :show-inheritance:
